@@ -15,22 +15,6 @@ from goats.core import variable
 T = typing.TypeVar('T')
 
 
-class Metadata(collections.UserDict):
-    """Metadata attributes relevant to a dataset axis."""
-
-    def __init__(
-        self,
-        name: typing.Union[str, typing.Iterable[str]]=None,
-        unit: typing.Union[str, metric.Unit]=None,
-    ) -> None:
-        attrs = {}
-        if name is not None:
-            attrs['name'] = metadata.Name(name)
-        if unit is not None:
-            attrs['unit'] = metadata.Unit(unit)
-        super().__init__(attrs)
-
-
 class Indexer(iterables.ReprStrMixin):
     """An object that computes axis indices from user values."""
 
@@ -67,14 +51,41 @@ class Indexer(iterables.ReprStrMixin):
         return f"{self._method.__qualname__}, size={self.size}"
 
 
+class IndexTypeError(Exception):
+    """Invalid index argument."""
+
+
+def indexer(n: int):
+    """Create an instance of the default axis-indexer."""
+    def method(targets):
+        try:
+            indices = [int(arg) for arg in targets]
+            if all(0 <= idx < n for idx in indices):
+                return index.Data(indices)
+        except TypeError as err:
+            raise IndexTypeError(
+                f"Can't convert {targets!r} to integer indices."
+            ) from err
+        raise ValueError(
+            f"One or more index in {targets} is outside the interval"
+            f" [0, {n-1}]"
+        ) from None
+    method.__qualname__ = "default"
+    return Indexer(method, n)
+
+
 Instance = typing.TypeVar('Instance', bound='Quantity')
 
 
-class Quantity:
+class Quantity(iterables.ReprStrMixin):
     """A callable representation of a dataset axis."""
 
     @typing.overload
-    def __init__(self, __computer: Indexer, **meta) -> None:
+    def __init__(
+        self,
+        __computer: Indexer,
+        unit: typing.Union[str, metric.Unit]=None,
+    ) -> None:
         """Create a new axis from scratch."""
 
     @typing.overload
@@ -87,20 +98,15 @@ class Quantity:
             return __a
         return super().__new__(cls)
 
-    def __init__(self, __a: Indexer, **meta) -> None:
+    def __init__(self, __a: Indexer, unit=None) -> None:
         self._indexer = __a
-        self._meta = meta
+        self._unit = metadata.Unit(unit) if unit else None
         self._reference = None
 
-    @property
-    def name(self) -> metadata.Name:
-        """The name of this axis."""
-        return self._meta.get('name')
-
     @property
     def unit(self) -> metadata.Unit:
         """The unit of this axis's values."""
-        return self._meta.get('unit')
+        return self._unit
 
     @property
     def reference(self):
@@ -115,10 +121,9 @@ class Quantity:
         unit = kwargs.pop('unit', self.unit)
         if unit:
             data = self._indexer.compute(targets, unit, **kwargs)
-            meta = {**self._meta, 'unit': unit}
-            return index.Quantity(data, **meta)
+            return index.Quantity(data, unit=unit)
         data = self._indexer.compute(targets, **kwargs)
-        return index.Quantity(data, **self._meta)
+        return index.Quantity(data, unit=unit)
 
     # NOTE: The following unit-related logic includes significant overlap with
     # `measurable.Quantity`.
@@ -152,111 +157,12 @@ class Quantity:
             return self
         new = metadata.Unit(unit)
         if self.unit | new:
-            return type(self)(self._indexer, unit=new, name=self.name)
+            return type(self)(self._indexer, unit=new)
         raise ValueError(
             f"The unit {str(unit)!r} is inconsistent with {str(self.unit)!r}"
         ) from None
 
     def __str__(self) -> str:
         """A simplified representation of this object."""
-        return ', '.join(f"{k}={str(v)!r}" for k, v in self._meta.items())
-
-
-class IndexTypeError(Exception):
-    """Invalid index argument."""
-
-
-class Interface(aliased.MutableMapping):
-    """An interface to the array axes available from a dataset."""
-
-    def __init__(
-        self,
-        dataset: datafile.Interface,
-        system: typing.Union[str, metric.System]=None,
-    ) -> None:
-        self.dataset = dataset
-        """The dataset to which these axes belong."""
-        self._variables = None
-        self._system = metric.System(system or 'mks')
-        indexers = {
-            k: self.build_default(k)
-            for k in self.dataset.axes.keys(aliased=True)
-        }
-        super().__init__(indexers)
-
-    @property
-    def variables(self):
-        """The variable quantities that these axes support."""
-        if self._variables is None:
-            self._variables = variable.Interface(
-                self.dataset,
-                system=self.system,
-            )
-        return self._variables
-
-    @property
-    def system(self):
-        """The metric system of these axes."""
-        return self._system
-
-    def __getitem__(self, __k: str):
-        """Get the named axis object, if possible."""
-        try:
-            method = self._get_indexer(__k)
-        except KeyError as err:
-            raise KeyError(
-                f"No known indexing method for {__k}"
-            ) from err
-        meta = self.get_metadata(__k)
-        return Quantity(method, **meta)
-
-    def _get_indexer(self, key: str):
-        """Get the axis indexer for `key`, or use the default."""
-        if key in self.keys():
-            return super().__getitem__(key)
-        raise KeyError(f"No indexing method for axis {key!r}")
-
-    def build_default(self, key: str):
-        """Define the default axis-indexer method."""
-        n = self.dataset.axes[key].size
-        def method(targets):
-            try:
-                indices = [int(arg) for arg in targets]
-                if all(0 <= idx < n for idx in indices):
-                    return index.Data(indices)
-            except TypeError as err:
-                raise IndexTypeError(
-                    f"Can't convert {targets!r} to integer indices."
-                ) from err
-            raise ValueError(
-                f"One or more index {targets} is outside the interval"
-                " [0, {n-1}]"
-            ) from None
-        return Indexer(method, n)
-
-    def get_metadata(self, key: str):
-        """Get metadata attributes corresponding to `key`."""
-        name = reference.NAMES.get(key, key)
-        try:
-            unit = self.variables[key].unit
-        except KeyError:
-            unit = None
-        return Metadata(name=name, unit=unit)
-
-    def resolve(
-        self,
-        names: typing.Iterable[str],
-        mode: str='strict',
-    ) -> typing.Tuple[str]:
-        """Compute and order the available axes in `names`."""
-        axes = self.dataset.available('axes').canonical
-        ordered = tuple(name for name in axes if name in names)
-        if mode == 'strict':
-            return ordered
-        extra = tuple(name for name in names if name not in ordered)
-        if not extra:
-            return ordered
-        if mode == 'append':
-            return ordered + extra
-        raise ValueError(f"Unrecognized mode {mode!r}")
+        return f"{self._indexer}, unit={str(self.unit)!r}"
 
