@@ -443,7 +443,7 @@ class Method(collections.abc.Mapping, iterables.ReprStrMixin):
         floats = []
         for name in self.parameters:
             arg = dependencies[name]
-            if isinstance(arg, physical.Array):
+            if isinstance(arg, variable.Quantity):
                 arrays.append(numpy.array(arg))
             elif isinstance(arg, physical.Scalar):
                 floats.append(float(arg))
@@ -476,28 +476,25 @@ class Method(collections.abc.Mapping, iterables.ReprStrMixin):
         return f"{self.name}{self.signature}"
 
 
-class Metadata(
-    metadata.NameMixin,
-    metadata.AxesMixin,
-): ...
-
-class Quantity(Metadata, iterables.ReprStrMixin):
+class Quantity(iterables.ReprStrMixin):
     """A callable quantity that produces a variable quantity."""
 
     def __init__(
         self,
         __method: Method,
-        *,
-        axes: typing.Iterable[str],
+        dimensions: typing.Iterable[str]=None,
         unit: metadata.UnitLike=None,
-        name: typing.Union[str, typing.Iterable[str]]=None,
     ) -> None:
         self.method = __method
-        self._axes = axes
+        self._dimensions = dimensions
         self._unit = unit
-        self._name = name
         self._parameters = None
 
+    @property
+    def dimensions(self):
+        """This quantity's indexable axes."""
+        return metadata.Dimensions(self._dimensions)
+
     @property
     def unit(self):
         """This quantity's metric unit."""
@@ -525,94 +522,15 @@ class Quantity(Metadata, iterables.ReprStrMixin):
         """Create a variable quantity from input quantities."""
         return variable.Quantity(
             self.method.compute(**quantities),
-            axes=self.axes,
+            dimensions=self.dimensions,
             unit=self.unit,
-            name=self.name,
         )
 
     def __str__(self) -> str:
         attrs = [
             self.method.name,
-            f"axes={self.axes}",
+            f"dimensions={self.dimensions}",
             f"unit={str(self.unit)!r}",
         ]
         return ', '.join(attrs)
 
-
-class Interface(aliased.Mapping):
-    """An interface to computable quantities."""
-
-    def __init__(
-        self,
-        axes: axis.Interface,
-        variables: variable.Interface,
-    ) -> None:
-        super().__init__(registry, keymap=reference.ALIASES)
-        self.axes = axes
-        self.variables = variables
-        self._cache = {}
-
-    def __getitem__(self, __k: str) -> Quantity:
-        if 'quantity' not in self._cache:
-            self._cache['quantity'] = {}
-        if __k in self._cache['quantity']:
-            return self._cache['quantity'][__k]
-        quantity = Quantity(
-            self.get_method(__k),
-            axes=self.get_axes(__k),
-            unit=self.get_unit(__k),
-            name=self.get_name(__k),
-        )
-        self._cache['quantity'][__k] = quantity
-        return quantity
-
-    def get_method(self, key: str):
-        """Get a `~computable.Method` for `key`."""
-        try:
-            this = super().__getitem__(key).copy()
-        except KeyError:
-            return None
-        else:
-            method = this.pop('method')
-            return Method(method, **this)
-
-    def get_name(self, key: str):
-        """Get the set of aliases for `key`."""
-        return self.alias(key, include=True)
-
-    def get_unit(self, key: str):
-        """Determine the unit of `key` based on its metric quantity."""
-        this = reference.METADATA.get(key, {}).get('quantity')
-        return self.variables.system.get_unit(quantity=this)
-
-    def get_axes(self, key: str):
-        """Compute appropriate axis names for `key`."""
-        if 'axes' not in self._cache:
-            self._cache['axes'] = {}
-        if key in self._cache['axes']:
-            return self._cache['axes'][key]
-        method = self.get_method(key)
-        self._removed = self._get_metadata(method, 'removed')
-        self._added = self._get_metadata(method, 'added')
-        self._accumulated = []
-        axes = self._gather_axes(method)
-        self._cache['axes'][key] = axes
-        return axes
-
-    def _gather_axes(self, target: Method):
-        """Recursively gather appropriate axes."""
-        for parameter in target.parameters:
-            if parameter in self.variables:
-                self._accumulated.extend(self.variables[parameter].axes)
-            elif method := self.get_method(parameter):
-                self._removed.extend(self._get_metadata(method, 'removed'))
-                self._added.extend(self._get_metadata(method, 'added'))
-                self._accumulated.extend(self._gather_axes(method))
-        unique = set(self._accumulated) - set(self._removed) | set(self._added)
-        return self.axes.resolve(unique, mode='append')
-
-    def _get_metadata(self, method: Method, key: str) -> list:
-        """Helper for accessing a method's metadata dictionary."""
-        value = method.get(key)
-        return list(iterables.whole(value)) if value else []
-
