@@ -43,7 +43,7 @@ class Quantity(collections.abc.Sequence):
     def __init__(
         self,
         __data: Data,
-        **meta,
+        unit: typing.Union[str, metric.Unit]=None,
     ) -> None:
         self._points = __data.points
         try:
@@ -52,8 +52,6 @@ class Quantity(collections.abc.Sequence):
             self._values = tuple(__data.values)
         else:
             self._values = __data.values
-        self._name = metadata.Name(meta.get('name', '<anonymous>'))
-        unit = meta.get('unit')
         self._unit = metadata.Unit(unit) if unit else None
 
     def __getitem__(self, __i: typing.SupportsIndex):
@@ -71,11 +69,6 @@ class Quantity(collections.abc.Sequence):
         """The axis value at each index."""
         return self._values
 
-    @property
-    def name(self):
-        """The name of the axis that these indices represent."""
-        return self._name
-
     @property
     def unit(self):
         """The metric unit of the corresponding values, if any."""
@@ -111,11 +104,10 @@ class Quantity(collections.abc.Sequence):
             prefix=prefix,
             suffix=suffix,
         )
-        parts = []
-        for key in ('name', 'unit'):
-            if v := getattr(self, key, None):
-                parts.append(f'{key}={str(v)!r}')
-        string = ', '.join([values, *parts])
+        parts = [values]
+        if self.unit:
+            parts.append(f"unit={str(self.unit)!r}")
+        string = ', '.join(parts)
         return f"{prefix}{string}{suffix}"
 
 
@@ -142,7 +134,10 @@ class Array(Quantity):
     def __init__(self, arg, **meta) -> None:
         if not meta and isinstance(arg, Quantity):
             data = Data(arg._points, values=arg.values)
-            return super().__init__(data, name=arg.name, unit=arg.unit)
+            return super().__init__(
+                data,
+                unit=arg.unit,
+            )
         super().__init__(arg, **meta)
 
     def __array__(self, *args, **kwargs):
@@ -187,7 +182,6 @@ class Array(Quantity):
             return type(self)(
                 Data(self._points, values=values),
                 unit=new,
-                name=self.name,
             )
         raise ValueError(
             f"The unit {str(unit)!r} is inconsistent with {str(self.unit)!r}"
