@@ -458,39 +458,53 @@ class ConfigKeyError(KeyError):
 class ConfigFile(iterables.MappingBase):
     """A class to handle EPREM run configuration files.
 
-    Parameters
-    ---------------------
-    filepath : string or path
-        The full path to the simulation-run config file to read. This class will
-        convert to input string or `pathlib.Path` object into a fully-qualified
-        read-only path.
-
-    comments : list of strings, default='#'
-        List of single-character strings to interpret as signifying a comment
-        line. This method will automatically ignore lines that begin with either
-        the empty string or the newline character.
-
     Notes
     -----
     This interface was designed to provide a faithful representation of the
     information in a given configuration file. A few notable consequences are as
     follows:
+
     - The look-up methods do not accept aliases as keys.
     - The parsing routine does not attempt to cast parsed values from strings to
       their underlying types, meaning all values are internally represented as
       strings. This only applies to each instance as a whole, since the object
       returned by look-up methods may perform type casting.
     - The unit associated with a specific value, when available, are those
-      consistent with the convetions of EPREM (cf. configuration.c) and do not
-      necessarily conform to a particular unit system. For example, many
-      reference lengths or distances (e.g., reference mean free path or observer
-      positions) are in au despite the fact that EPREM works with lengths in cm.
+      consistent with the configuration conventions of EPREM (cf.
+      ``src/configuration.c``) and do not necessarily conform to a particular
+      unit system. For example, many reference lengths or distances (e.g.,
+      reference mean free path or observer positions) are in 'au' despite the
+      fact that EPREM internally works with lengths in cm.
     """
     def __init__(
         self,
-        filepath: typing.Union[str, pathlib.Path],
+        filepath: iotools.PathLike,
         comments: typing.List[str]=None,
     ) -> None:
+        """Create an instance.
+
+        Parameters
+        ---------------------
+        filepath : string or path
+            The path to the simulation-run config file to read. This class will
+            convert the argument to a fully-qualified read-only path.
+
+        comments : list of strings, default='#'
+            List of single-character strings to interpret as signifying a
+            comment line. This method will automatically ignore lines that begin
+            with either the empty string or the newline character.
+
+        Notes
+        -----
+        * The argument to `filepath` may be relative but it must include the
+          file name. For example, suppose the relevant configuration file is
+          called `config.ini`. Then, passing `filepath='config.ini'` or
+          `filepath='./config.ini'` within the containing directory, as well as
+          `filepath='</path/to/dir>/config.ini'` elsewhere (even if
+          `/path/to/dir` is relative), would be valid, but passing
+          `filepath='</path/to/dir>'` (even if `/path/to/dir` is absolute) would
+          not be valid.
+        """
         self.filepath = iotools.ReadOnlyPath(filepath)
         self.comments = comments or ['#']
         self.KeyError = ConfigKeyError
@@ -536,7 +550,7 @@ class Runtime(iterables.MappingBase):
 
     def __init__(
         self,
-        source_path: iotools.PathLike,
+        source_path: iotools.PathLike=None,
         config_path: iotools.PathLike=None,
         **kwargs
     ) -> None:
@@ -566,8 +580,6 @@ class Runtime(iterables.MappingBase):
         self._basetypes = None
         self._reference = None
         super().__init__(tuple(self.reference))
-        # BUG: These `kwargs` will persist even if the user updates the
-        # config-file path, which could create an inconsistency.
         self._kwargs = kwargs
         self._current = None
 
@@ -666,10 +678,14 @@ class Runtime(iterables.MappingBase):
         raise TypeError(f"Can't resolve {definition!r}") from None
 
     def _compute_sum(self, arg: str) -> numbers.Real:
-        """Compute the sum of two known parameters."""
-        # HACK: This is only designed to handle strings that contain a single
-        # additive operator joining two arguments that `_evaluate` already knows
-        # how to handle.
+        """Compute the sum of two known parameters.
+        
+        Notes
+        -----
+        This is only designed to handle strings that contain a single additive
+        operator joining two arguments that `_evaluate` already knows how to
+        handle.
+        """
         for operator in ('+', '-'):
             if operator in arg:
                 terms = [
@@ -713,30 +729,37 @@ class Runtime(iterables.MappingBase):
 class Arguments(constant.Interface):
     """Aliased access to EPREM parameter arguments."""
 
+    @typing.overload
     def __init__(
         self,
-        runtime: Runtime=None,
-        **runtime_init,
+        source_path: iotools.PathLike,
+        config_path: iotools.PathLike,
+        **kwargs
     ) -> None:
-        """Initialize an instance of this class.
-
-        The caller may pass an existing instance of `~parameters.Runtime` or the
-        arguments necessary to create the appropriate instance. See
-        documentation at `~parameters.Runtime` for information. Note that this
-        class will use an existing instance of `~parameters.Runtime` if
-        available, without checking for the presence of additional arguments.
-
+        """Create an interface from paths.
+        
         Parameters
         ----------
-        runtime : optional
-            An instance of `parameters.Runtime` initialized with paths relevant
-            to the simulation run under analysis.
-
-        **runtime_init : optional
-            See `~parameters.Runtime`.
+        See `~runtime.Runtime`.
         """
-        runtime = runtime or Runtime(**runtime_init)
-        super().__init__(self._build_mapping(runtime))
+
+    @typing.overload
+    def __init__(self, __runtime: Runtime) -> None:
+        """Create an interface from a runtime mapping.
+        
+        Parameters
+        ----------
+        runtime
+            An instance of `~parameters.Runtime` initialized with paths relevant
+            to the simulation run under analysis.
+        """
+
+    def __init__(self, *args, **kwargs) -> None:
+        if not kwargs and len(args) == 1:
+            arg = args[0]
+            if isinstance(arg, Runtime):
+                return super().__init__(self._build_mapping(arg))
+        super().__init__(self._build_mapping(Runtime(*args, **kwargs)))
 
     def _build_mapping(self, runtime: Runtime):
         """Build the mapping of available parameters."""
@@ -758,6 +781,167 @@ class Arguments(constant.Interface):
         return aliased.MutableMapping(base)
 
 
+class Interface(aliased.Mapping):
+    """An interface to EPREM parameters."""
+
+    def __init__(self, path: iotools.PathLike=None, **opts) -> None:
+        """
+        Parameters
+        ----------
+        path : path-like, default=None
+            The location of the EPREM configuration file containing
+            user-provided parameter values for a particular EPREM simulation
+            run. May be omitted, in which case this class will use default
+            argument values.
+
+        **opts
+            Options for loading the configuration file. See
+            `~runtime.ConfigFile` for more information.
+
+        Notes
+        -----
+        Path-like arguments may be any path-like object (e.g., `str`,
+        `pathlib.Path`), may be relative, and may contain standard wildcard
+        characters (e.g., `~`).
+        """
+        runtime = Runtime(config_path=path)
+        values = {
+            **{
+                key: info.get('default')
+                for key, info in _LOCAL.items()
+            },
+            **dict(runtime),
+        }
+        keys = tuple(set(tuple(_LOCAL) + tuple(runtime)))
+        base = {
+            (key, *_ALIASES.get(key, [])): {
+                'unit': _UNITS.get(key),
+                'value': values.get(key),
+            }
+            for key in keys
+        }
+        super().__init__(base)
+        self._user = ConfigFile(path, **opts) if path else {}
+        self._reference = ConfigurationC()
+        self._basetypes = BaseTypesH()
+        self._current = None
+
+    def __getitem__(self, __k: str):
+        """Create the appropriate object for the named parameter."""
+        try:
+            this = super().__getitem__(__k)
+        except KeyError:
+            raise KeyError(f"No parameter corresponding to {__k!r}") from None
+        value = this['value']
+        aliases = self.alias(__k, include=True)
+        if unit := this['unit']:
+            return constant.Assumption(value, unit=unit, name=aliases)
+        return constant.Option(value, name=aliases)
+
+    @property
+    def basetypes(self):
+        """Values of constants defined in EPREM `src/baseTypes.h`."""
+        return self._basetypes
+
+    @property
+    def user(self) -> typing.Mapping[str, str]:
+        """The user-provided parameter values."""
+        return self._user
+
+    @property
+    def reference(self):
+        """Parameter metadata from EPREM `src/configuration.c`."""
+        return self._reference
+
+    _special_cases = {
+        'N_PROCS': None,
+        'third': 1/3,
+    }
+
+    def _evaluate(self, current: typing.Union[str, numbers.Real]):
+        """Compute the final value of a parameter."""
+        if isinstance(current, numbers.Real):
+            return current
+        if value := numerical.cast(current, strict=False):
+            return value
+        if current in self._special_cases:
+            return self._special_cases[current]
+        argument = self._get_argument(current)
+        if argument is not None:
+            definition = argument['definition']
+            if isinstance(definition, argument['type']):
+                return definition
+            return self._evaluate(definition)
+        if isinstance(current, str):
+            return self._decompose(current)
+        raise TypeError(f"Can't evaluate {current!r}") from None
+
+    _struct_member = re.compile(r'\Aconfig\.\w*\Z')
+
+    def _decompose(self, definition: str):
+        """Split a parameter definition into simpler components."""
+        if self._struct_member.match(definition):
+            return self._evaluate(definition.replace('config.', ''))
+        if result := self._compute_sum(definition):
+            return result
+        if any(c in definition for c in {'*', '/'}):
+            expression = symbolic.Expression(definition)
+            evaluated = [
+                term.coefficient * self._evaluate(term.base)**term.exponent
+                for term in expression
+            ]
+            return functools.reduce(lambda x,y: x*y, evaluated)
+        raise TypeError(f"Can't decompose {definition!r}") from None
+
+    def _compute_sum(self, arg: str) -> numbers.Real:
+        """Compute the sum of two known parameters.
+        
+        Notes
+        -----
+        This is only designed to handle strings that contain a single additive
+        operator joining two arguments that `_evaluate` already knows how to
+        handle.
+        """
+        for operator in ('+', '-'):
+            if operator in arg:
+                terms = [
+                    self._evaluate(s.strip())
+                    for s in arg.split(operator)
+                ]
+                return terms[0] + float(f'{operator}1')*terms[1]
+
+    def _get_argument(self, name: str):
+        """Get the current definition and type of a parameter."""
+        if self._current is None:
+            self._current = {
+                key: self._convert(
+                    self.user.get(key) or parameter['default'],
+                    parameter['type'],
+                )
+                for key, parameter in self.reference.items()
+            }
+        if name in self._current:
+            return {
+                'definition': self._current[name],
+                'type': self.reference[name]['type']
+            }
+        if name in self.basetypes:
+            return {
+                'definition': self.basetypes[name],
+                'type': type(self.basetypes[name]),
+            }
+
+    def _convert(self, arg: typing.Union[str, _RT], realtype: _RT):
+        """Convert `arg` to its real type, if necessary and possible."""
+        if isinstance(arg, realtype):
+            return arg
+        if realtype in {int, float}:
+            return soft_convert(arg, realtype)
+        if realtype == list:
+            return soft_convert(arg, iterables.string_to_list)
+        return arg
+
+
 _LOCAL = {
     'minimum_energy': {
         'aliases': ['Emin', 'minimum energy'],
